==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/zh-CN/admin/users/general.php <==
<?php

return [
    'activated_help_text' => '该用户可以登录',
    'activated_disabled_help_text' => '您无法编辑自己帐户的激活状态。',
    'assets_user'       => '分配给:name的资产',
    'bulk_update_warn'	=> '您即将编辑user_count用户的属性。请注意，您不能使用此表单更改您自己的用户属性，必须单独对您自己的用户信息进行编辑。',
    'bulk_update_help'	=> '此表单允许您一次更新多个用户。仅填写您需要更改的字段。留的空的任何字段将保持不变。',
    'current_assets'    => '资产当前借出给该用户',
    'clone'             => '克隆用户',
    'contact_user'      => '联系 :name',
    'edit'              => '编辑用户',
    'filetype_info'     => '允许的文件类型有： png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar',
    'history_user'      => ':name的历史',
    'info'				=> '信息',
    'restore_user'		=> '单击此处可将其还原。',
    'last_login'        => '上一次登陆',
    'ldap_config_text'  => 'LDAP配置在 管理 > 设置。所选位置将为导入的用户所用',
    'print_assigned'    => '打印所有已分配资产',
    'email_assigned'    => '邮件发送所有已分配的列表',
    'user_notified'     => '用户已通过电子邮件收到当前分配给他们的物品列表。',
    'auto_assign_label' => '在自动分配符合条件的许可证时包括此用户',
    'auto_assign_help'  => '在自动分配许可证时跳过此用户',
    'software_user'     => ':name 借走的软件',
    'send_email_help'   => '您必须为此用户提供电子邮件地址才能发送他们的凭据。电子邮件凭据只能在用户创建时完成。 密码存储在单向散列中，保存后无法检索。',
    'view_user'         => '查看用户： :name',
    'usercsv'           => 'CSV 档案',
    'two_factor_admin_optin_help' => '您当前的管理员设置允许使用双重认证。 ',
    'two_factor_enrolled' => '双重认证设备已录入 ',
    'two_factor_active'   => '双重认证激活 ',
    'user_deactivated'  => '用户无法登录',
    'user_activated'  => '用户可以登录',
    'activation_status_warning' => '不要改变激活状态',
    'group_memberships_helpblock' => '只有超级管理员可以编辑群组成员。',
    'superadmin_permission_warning' => '只有超级管理员可以授予用户超级管理员访问权限。',
    'admin_permission_warning' => '只有拥有管理员权限或更大权限的用户才能授予用户管理员权限。',
    'remove_group_memberships' => '删除群组成员',
    'warning_deletion_information' => '下列 :count 个用户的所有物品将要归还。超级管理员名称高亮为红色。',
    'update_user_assets_status' => '将这些用户的所有资产更新到此状态',
    'checkin_user_properties' => '归还与这些用户相关的所有资产',
    'remote_label'   => '这是一个远程用户',
    'remote'   => '远程',
    'remote_help' => '如果您需要对从不进入或很少进入您的实体地点的远程用户进行筛选，这将非常有用。',
    'not_remote_label' => '这不是一个远程用户',
    'vip_label' => 'VIP用户',
    'vip_help' => '如果您想以特殊方式处理重要的人，这将有助于在您的组织中标记他们。',
    'create_user' => '新建用户',
    'create_user_page_explanation' => '这是您将用于首次访问该站点的账户信息。',
    'email_credentials' => '电子邮件凭据',
    'email_credentials_text' => '将我的凭据发送到上述电子邮件地址',
    'next_save_user' => '下一步：保存用户',
    'all_assigned_list_generation' => '生成于：',
    'email_user_creds_on_create' => '给此用户发电子邮件？',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/zh-CN/admin/users/general.php <==
<?php

return [
    'activated_help_text' => '该用户可以登录',
    'activated_disabled_help_text' => '您无法编辑自己帐户的激活状态。',
    'assets_user'       => '分配给:name的资产',
    'bulk_update_warn'	=> '您即将编辑user_count用户的属性。请注意，您不能使用此表单更改您自己的用户属性，必须单独对您自己的用户信息进行编辑。',
    'bulk_update_help'	=> '此表单允许您一次更新多个用户。仅填写您需要更改的字段。留的空的任何字段将保持不变。',
    'current_assets'    => '资产当前借出给该用户',
    'clone'             => '克隆用户',
    'contact_user'      => '联系 :name',
    'edit'              => '编辑用户',
    'filetype_info'     => '允许的文件类型有： png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar',
    'history_user'      => ':name的历史',
    'info'				=> '信息',
    'restore_user'		=> '单击此处可将其还原。',
    'last_login'        => '上一次登陆',
    'ldap_config_text'  => 'LDAP配置在 管理 > 设置。所选位置将为导入的用户所用',
    'print_assigned'    => '打印所有已分配资产',
    'email_assigned'    => '邮件发送所有已分配的列表',
    'user_notified'     => '用户已通过电子邮件收到当前分配给他们的物品列表。',
    'users_notified'    => '已通过电子邮件向该用户发送了其当前分配项目的列表。|:count 位用户已通过电子邮件收到其当前分配项目的列表。',
    'users_notified_warning' => ':count 位用户已通过电子邮件收到了其当前分配项目的列表，但是 :no_email 用户没有电子邮件地址，因此无法收到电子邮件。| :count 位用户已通过电子邮件收到了其当前分配项目的列表，但是 :no_email 用户没有电子邮件地址，因此无法收到电子邮件。',
    'auto_assign_label' => '在自动分配符合条件的许可证时包括此用户',
    'auto_assign_help'  => '在自动分配许可证时跳过此用户',
    'software_user'     => ':name 借走的软件',
    'send_email_help'   => '您必须为此用户提供电子邮件地址才能发送他们的凭据。电子邮件凭据只能在用户创建时完成。 密码存储在单向散列中，保存后无法检索。',
    'view_user'         => '查看用户： :name',
    'usercsv'           => 'CSV 档案',
    'two_factor_admin_optin_help' => '您当前的管理员设置允许使用双重认证。 ',
    'two_factor_enrolled' => '双重认证设备已录入 ',
    'two_factor_active'   => '双重认证激活 ',
    'user_deactivated'  => '用户无法登录',
    'user_activated'  => '用户可以登录',
    'activation_status_warning' => '不要改变激活状态',
    'group_memberships_helpblock' => '只有超级管理员可以编辑群组成员。',
    'superadmin_permission_warning' => '只有超级管理员可以授予用户超级管理员访问权限。',
    'admin_permission_warning' => '只有拥有管理员权限或更大权限的用户才能授予用户管理员权限。',
    'remove_group_memberships' => '删除群组成员',
    'warning_deletion_information' => '下列 :count 个用户的所有物品将要归还。超级管理员名称高亮为红色。',
    'update_user_assets_status' => '将这些用户的所有资产更新到此状态',
    'checkin_user_properties' => '归还与这些用户相关的所有资产',
    'remote_label'   => '这是一个远程用户',
    'remote'   => '远程',
    'remote_help' => '如果您需要对从不进入或很少进入您的实体地点的远程用户进行筛选，这将非常有用。',
    'not_remote_label' => '这不是一个远程用户',
    'vip_label' => 'VIP用户',
    'vip_help' => '如果您想以特殊方式处理重要的人，这将有助于在您的组织中标记他们。',
    'create_user' => '新建用户',
    'create_user_page_explanation' => '这是您将用于首次访问该站点的账户信息。',
    'email_credentials' => '电子邮件凭据',
    'email_credentials_text' => '将我的凭据发送到上述电子邮件地址',
    'next_save_user' => '下一步：保存用户',
    'all_assigned_list_generation' => '生成于：',
    'email_user_creds_on_create' => '给此用户发电子邮件？',
];
